<?php

namespace FiloBlu\Storelocator\Controller\Adminhtml\Stores;

use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\ResultFactory;
use Magento\Ui\Component\MassAction\Filter;
use FiloBlu\Storelocator\Model\ResourceModel\Stores\CollectionFactory;

/**
 * Class MassRemoveGmb
 */
class MassRemoveGmb extends \Magento\Backend\App\Action {

    /**
     * @var PageFactory
     */
    protected $resultPageFactory;

    /**
     * @var Filter
     */
    protected $filter;

    /**
     * @var CollectionFactory
     */
    protected $collectionFactory;
    protected $_googleApi;
    protected $config = null;

    /**
     * @param Context $context
     * @param PageFactory $resultPageFactory
     */
    public function __construct(
    Context $context, Filter $filter, CollectionFactory $collectionFactory, \FiloBlu\Storelocator\Model\Google\Api $googleApi, \Magento\Framework\App\Config\ScopeConfigInterface $config
    ) {
        $this->filter = $filter;
        $this->collectionFactory = $collectionFactory;
        $this->_googleApi = $googleApi;
        $this->config = $config;


        parent::__construct($context);
    }

    /**
     * Index action
     *
     * @return \Magento\Backend\Model\View\Result\Page
     */
    public function execute() {
        if (!$this->config->getValue('filoblu_storelocator_section/google_my_business/gmb_enabled')) {
            $this->messageManager->addError(__('Google My Business Integration is not enabled'));
        } else {

            if ($this->_googleApi->getClient()->isAccessTokenExpired()) {
                $this->messageManager->addError(__('Access token expired. Please go to [ System -> Configuration -> FiloBlu -> Storelocator -> Google My Business ] to login in'));
            } else {
                $collection = $this->filter->getCollection($this->collectionFactory->create());

                foreach ($collection as $store) {

                    if ($store->getGmbLocationName()) {

                        $objReturn = $this->_googleApi->deleteLocation($store->getGmbLocationName());

                        if (!is_string($objReturn)) {
                            $this->messageManager->addSuccess(__('StoreID:' . $store->getId() . " deleted from Google My Business"));
                        } else {
                            $this->messageManager->addError(__('Error deleting StoreID:' . $store->getId() . " - Message: " . $objReturn));
                        }
                    } else {
                        $this->messageManager->addNotice(__('Error for StoreID:' . $store->getId() . " - Never sent to Google My Business, nothing to do"));
                    }
                    
                    $store->setGmbLocationName(null);
                    $store->save();
                }
            }
        }


        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return $resultRedirect->setPath('*/*/');
    }

    /**
     * Is the user allowed to view the store grid.
     *
     * @return bool
     */
    protected function _isAllowed() {
        return $this->_authorization->isAllowed('FiloBlu_Storelocator::storelocator');
    }

}
